
.. _/main:

*************
Block Manager
*************

Block Manager provides an API to manage block devices (inspect, format, mount).

.. ............................................................................
.. _/main/use_cases:

Use Cases
=========

Partition disks.

Set up disk partition table, partition types and file system.

Mount partitions.

.. ............................................................................
.. _/main/installing:

Installing
==========

Install with PyPI.

.. code-block:: console

   pip3 install blkmgr

.. ............................................................................
.. _/main/links:

Links
=====

`GitLab repository <https://gitlab.com/srhuerzeler/blkmgr>`_

`PyPI package <https://pypi.org/project/blkmgr>`_

